Introduction
============

.. include:: includes/all.rst

The ``debops-contrib.fuse`` role allows you to install and configure Filesystem
in Userspace (FUSE).


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.1.3``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops-contrib.fuse

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
